#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:33
# @Author   : Peter
# @Des       : 
# @File        : P{ost
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String, Text
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class PostBaseModel(object):

    @classmethod
    def getBySpiderWebIdFloor(cls, spider, web_id, floor, session):
        return session.query(cls).filter(cls.spider == spider, cls.bbs_web_id == web_id, cls.bbs_floor == floor).all()


class PostModel(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post'

    id = Column(Integer, primary_key=True)
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(Integer)
    bbs_reply_floor = Column(Integer)
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_reply_floor = kw.get("bbs_reply_floor", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostsModel(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_posts'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel09(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_09'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel10(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_10'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel11(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_11'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel12(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_12'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel13(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_13'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel14(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_14'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel15(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_15'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel16(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_16'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel17(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_17'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel18(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_18'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel19(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_19'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)
