# # -*- encoding:utf8 -*-

# 代理数量
PROXY_NUM = 5
# 是否是测试环境
TEST = 0
MASTER = 1
# 代理超限的时候 单进程暂停时间
TS_429 = 1

# 代理信息
PROXY_UN = "HF60345RM388C8ZD"
PROXY_PWD = "F583670DE9072F1E"

# 核对爬虫天数
CHECK_DAYS = 10

HEADERS = {
    "Accept": "application/json, text/javascript, */*; q=0.01",
    "Accept-Encoding": "gzip, deflate",
    "Accept-Language": "zh-CN,zh;q=0.5",
    "Cache-Control": "max-age=0",
    "Connection": "keep-alive",
    "Upgrade-Insecure-Requests": "1",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.106 Safari/537.36",
}