#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/9/17 17:30
# @Author   : Peter
# @Des       : 
# @File        : CarDetailModel
# @Software: PyCharm
# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String, text
from sqlalchemy.dialects.mysql.types import TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class CarDetailModel(Base, BaseModel):
    __tablename__ = 'car_detail'

    id = Column(Integer, primary_key=True)
    car_id = Column(Integer, unique=True)
    car_web_id = Column(Integer)
    car_series_id = Column(Integer)
    car_level_id = Column(Integer)
    year = Column(String(10))
    k_1 = Column(String(250))
    k_2 = Column(String(250))
    k_3 = Column(String(25))
    k_4 = Column(String(25))
    k_5 = Column(String(25))
    k_6 = Column(String(25))
    k_7 = Column(String(25))
    k_8 = Column(String(25))
    k_9 = Column(String(25))
    k_10 = Column(String(25))
    k_11 = Column(String(25))
    k_12 = Column(String(25))
    k_13 = Column(String(25))
    k_14 = Column(String(25))
    k_15 = Column(String(25))
    k_16 = Column(String(25))
    k_17 = Column(String(25))
    k_18 = Column(String(25))
    k_19 = Column(String(25))
    k_20 = Column(String(25))
    k_21 = Column(String(25))
    k_22 = Column(String(25))
    k_23 = Column(String(25))
    k_24 = Column(String(25))
    k_25 = Column(String(25))
    k_26 = Column(String(25))
    k_27 = Column(String(25))
    k_28 = Column(String(25))
    k_29 = Column(String(25))
    k_30 = Column(String(25))
    k_31 = Column(String(25))
    k_32 = Column(String(25))
    k_33 = Column(String(25))
    k_34 = Column(String(25))
    k_35 = Column(String(25))
    k_36 = Column(String(25))
    k_37 = Column(String(25))
    k_38 = Column(String(25))
    k_39 = Column(String(25))
    k_40 = Column(String(25))
    k_41 = Column(String(25))
    k_42 = Column(String(25))
    k_43 = Column(String(25))
    k_44 = Column(String(25))
    k_45 = Column(String(25))
    k_46 = Column(String(25))
    k_47 = Column(String(25))
    k_48 = Column(String(25))
    k_49 = Column(String(25))
    k_50 = Column(String(25))
    k_51 = Column(String(25))
    k_52 = Column(String(25))
    k_53 = Column(String(25))
    k_54 = Column(String(25))
    k_55 = Column(String(25))
    k_56 = Column(String(25))
    k_57 = Column(String(25))
    k_58 = Column(String(25))
    k_59 = Column(String(25))
    k_60 = Column(String(25))
    k_61 = Column(String(25))
    k_62 = Column(String(25))
    k_63 = Column(String(25))
    k_64 = Column(String(25))
    k_65 = Column(String(25))
    k_66 = Column(String(25))
    k_67 = Column(String(25))
    k_68 = Column(String(25))
    k_69 = Column(String(25))
    k_70 = Column(String(25))
    k_71 = Column(String(25))
    k_72 = Column(String(25))
    k_73 = Column(String(25))
    k_74 = Column(String(25))
    k_75 = Column(String(25))
    k_76 = Column(String(25))
    k_77 = Column(String(25))
    k_78 = Column(String(25))
    k_79 = Column(String(25))
    k_80 = Column(String(25))
    k_81 = Column(String(25))
    k_82 = Column(String(25))
    k_83 = Column(String(25))
    k_84 = Column(String(25))
    k_85 = Column(String(25))
    k_86 = Column(String(25))
    k_87 = Column(String(25))
    k_88 = Column(String(25))
    k_89 = Column(String(25))
    k_90 = Column(String(25))
    k_91 = Column(String(25))
    k_92 = Column(String(25))
    k_93 = Column(String(25))
    k_94 = Column(String(25))
    k_95 = Column(String(25))
    k_96 = Column(String(25))
    k_97 = Column(String(25))
    k_98 = Column(String(25))
    k_99 = Column(String(25))
    k_100 = Column(String(25))
    k_101 = Column(String(25))
    k_102 = Column(String(25))
    k_103 = Column(String(25))
    k_104 = Column(String(25))
    k_105 = Column(String(25))
    k_106 = Column(String(25))
    k_107 = Column(String(25))
    k_108 = Column(String(25))
    k_109 = Column(String(25))
    k_110 = Column(String(25))
    k_111 = Column(String(25))
    k_112 = Column(String(25))
    k_113 = Column(String(25))
    k_114 = Column(String(25))
    k_115 = Column(String(25))
    k_116 = Column(String(25))
    k_117 = Column(String(25))
    k_118 = Column(String(25))
    k_119 = Column(String(25))
    k_120 = Column(String(25))
    k_121 = Column(String(25))
    k_122 = Column(String(25))
    k_123 = Column(String(25))
    k_124 = Column(String(25))
    k_125 = Column(String(25))
    k_126 = Column(String(25))
    k_127 = Column(String(25))
    k_128 = Column(String(25))
    k_129 = Column(String(25))
    k_130 = Column(String(25))
    k_131 = Column(String(25))
    k_132 = Column(String(25))
    k_133 = Column(String(25))
    k_134 = Column(String(25))
    k_135 = Column(String(25))
    k_136 = Column(String(25))
    k_137 = Column(String(25))
    k_138 = Column(String(25))
    k_139 = Column(String(25))
    k_140 = Column(String(25))
    k_141 = Column(String(25))
    k_142 = Column(String(25))
    k_143 = Column(String(25))
    k_144 = Column(String(25))
    k_145 = Column(String(25))
    k_146 = Column(String(25))
    k_147 = Column(String(25))
    k_148 = Column(String(25))
    k_149 = Column(String(25))
    k_150 = Column(String(25))
    k_151 = Column(String(25))
    k_152 = Column(String(25))
    k_153 = Column(String(25))
    k_154 = Column(String(25))
    k_155 = Column(String(25))
    k_156 = Column(String(25))
    k_157 = Column(String(25))
    k_158 = Column(String(25))
    k_159 = Column(String(25))
    k_160 = Column(String(25))
    k_161 = Column(String(25))
    k_162 = Column(String(25))
    k_163 = Column(String(25))
    k_164 = Column(String(25))
    k_165 = Column(String(25))
    k_166 = Column(String(25))
    k_167 = Column(String(25))
    k_168 = Column(String(25))
    k_169 = Column(String(25))
    k_170 = Column(String(25))
    k_171 = Column(String(25))
    k_172 = Column(String(25))
    k_173 = Column(String(25))
    k_174 = Column(String(25))
    k_175 = Column(String(25))
    k_176 = Column(String(25))
    k_177 = Column(String(25))
    k_178 = Column(String(25))
    k_179 = Column(String(25))
    k_180 = Column(String(25))
    k_181 = Column(String(25))
    k_182 = Column(String(25))
    k_183 = Column(String(25))
    k_184 = Column(String(25))
    k_185 = Column(String(25))
    k_186 = Column(String(25))
    k_187 = Column(String(25))
    k_188 = Column(String(25))
    k_189 = Column(String(25))
    k_190 = Column(String(25))
    k_191 = Column(String(25))
    k_192 = Column(String(25))
    k_193 = Column(String(25))
    k_194 = Column(String(25))
    k_195 = Column(String(25))
    k_196 = Column(String(25))
    k_197 = Column(String(25))
    k_198 = Column(String(25))
    k_199 = Column(String(25))
    k_200 = Column(String(25))
    k_201 = Column(String(25))
    k_202 = Column(String(25))
    k_203 = Column(String(25))
    k_204 = Column(String(25))
    k_205 = Column(String(25))
    k_206 = Column(String(25))
    k_207 = Column(String(25))
    k_208 = Column(String(25))
    k_209 = Column(String(25))
    k_210 = Column(String(25))
    k_211 = Column(String(25))
    k_212 = Column(String(25))
    k_213 = Column(String(25))
    k_214 = Column(String(25))
    k_215 = Column(String(25))
    k_216 = Column(String(25))
    k_217 = Column(String(25))
    k_218 = Column(String(25))
    k_219 = Column(String(25))
    k_220 = Column(String(25))
    k_221 = Column(String(25))
    k_222 = Column(String(25))
    k_223 = Column(String(25))
    k_224 = Column(String(25))
    k_225 = Column(String(25))
    k_226 = Column(String(25))
    k_227 = Column(String(25))
    k_228 = Column(String(25))
    k_229 = Column(String(25))
    k_230 = Column(String(25))
    k_231 = Column(String(25))
    k_232 = Column(String(25))
    k_233 = Column(String(25))
    k_234 = Column(String(25))
    k_235 = Column(String(25))
    k_236 = Column(String(25))
    k_237 = Column(String(25))
    k_238 = Column(String(25))
    k_239 = Column(String(25))
    k_240 = Column(String(25))
    k_241 = Column(String(25))
    k_242 = Column(String(25))
    k_243 = Column(String(25))
    k_244 = Column(String(25))
    k_245 = Column(String(25))
    k_246 = Column(String(25))
    k_247 = Column(String(25))
    k_248 = Column(String(25))
    k_249 = Column(String(25))
    k_250 = Column(String(25))
    k_251 = Column(String(25))
    k_252 = Column(String(25))
    k_253 = Column(String(25))
    k_254 = Column(String(25))
    k_255 = Column(String(25))
    k_256 = Column(String(25))
    k_257 = Column(String(25))
    k_258 = Column(String(25))
    k_259 = Column(String(25))
    k_260 = Column(String(25))
    k_261 = Column(String(25))
    k_262 = Column(String(25))
    k_263 = Column(String(25))
    k_264 = Column(String(25))
    k_265 = Column(String(25))
    k_266 = Column(String(25))
    k_267 = Column(String(25))
    k_268 = Column(String(25))
    k_269 = Column(String(25))
    k_270 = Column(String(25))
    k_271 = Column(String(25))
    k_272 = Column(String(25))
    k_273 = Column(String(25))
    k_274 = Column(String(25))
    k_275 = Column(String(25))
    k_276 = Column(String(25))
    k_277 = Column(String(25))
    k_278 = Column(String(25))
    k_279 = Column(String(25))
    k_280 = Column(String(25))
    k_281 = Column(String(25))
    k_282 = Column(String(25))
    k_283 = Column(String(25))
    k_284 = Column(String(25))
    k_285 = Column(String(25))
    k_286 = Column(String(25))
    k_287 = Column(String(25))
    k_288 = Column(String(25))
    k_289 = Column(String(25))
    k_290 = Column(String(25))
    k_291 = Column(String(25))
    k_292 = Column(String(25))
    k_293 = Column(String(25))
    k_294 = Column(String(25))
    k_295 = Column(String(25))
    k_296 = Column(String(25))
    k_297 = Column(String(25))
    k_298 = Column(String(25))
    k_299 = Column(String(25))
    k_300 = Column(String(25))
    k_301 = Column(String(25))
    k_302 = Column(String(25))
    k_303 = Column(String(25))
    k_304 = Column(String(25))
    k_305 = Column(String(25))
    k_306 = Column(String(25))
    k_307 = Column(String(25))
    k_308 = Column(String(25))
    k_309 = Column(String(25))
    k_310 = Column(String(25))
    k_311 = Column(String(25))
    k_312 = Column(String(25))
    k_313 = Column(String(25))
    k_314 = Column(String(25))
    is_del = Column(TINYINT(4), server_default=text("'0'"))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.car_id = kw.get("car_id", None)
        self.car_level_id = kw.get("car_level_id", None)
        self.car_series_id = kw.get("car_series_id", None)
        self.car_web_id = kw.get("car_web_id", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.k_1 = kw.get("k_1", None)
        self.k_10 = kw.get("k_10", None)
        self.k_100 = kw.get("k_100", None)
        self.k_101 = kw.get("k_101", None)
        self.k_102 = kw.get("k_102", None)
        self.k_103 = kw.get("k_103", None)
        self.k_104 = kw.get("k_104", None)
        self.k_105 = kw.get("k_105", None)
        self.k_106 = kw.get("k_106", None)
        self.k_107 = kw.get("k_107", None)
        self.k_108 = kw.get("k_108", None)
        self.k_109 = kw.get("k_109", None)
        self.k_11 = kw.get("k_11", None)
        self.k_110 = kw.get("k_110", None)
        self.k_111 = kw.get("k_111", None)
        self.k_112 = kw.get("k_112", None)
        self.k_113 = kw.get("k_113", None)
        self.k_114 = kw.get("k_114", None)
        self.k_115 = kw.get("k_115", None)
        self.k_116 = kw.get("k_116", None)
        self.k_117 = kw.get("k_117", None)
        self.k_118 = kw.get("k_118", None)
        self.k_119 = kw.get("k_119", None)
        self.k_12 = kw.get("k_12", None)
        self.k_120 = kw.get("k_120", None)
        self.k_121 = kw.get("k_121", None)
        self.k_122 = kw.get("k_122", None)
        self.k_123 = kw.get("k_123", None)
        self.k_124 = kw.get("k_124", None)
        self.k_125 = kw.get("k_125", None)
        self.k_126 = kw.get("k_126", None)
        self.k_127 = kw.get("k_127", None)
        self.k_128 = kw.get("k_128", None)
        self.k_129 = kw.get("k_129", None)
        self.k_13 = kw.get("k_13", None)
        self.k_130 = kw.get("k_130", None)
        self.k_131 = kw.get("k_131", None)
        self.k_132 = kw.get("k_132", None)
        self.k_133 = kw.get("k_133", None)
        self.k_134 = kw.get("k_134", None)
        self.k_135 = kw.get("k_135", None)
        self.k_136 = kw.get("k_136", None)
        self.k_137 = kw.get("k_137", None)
        self.k_138 = kw.get("k_138", None)
        self.k_139 = kw.get("k_139", None)
        self.k_14 = kw.get("k_14", None)
        self.k_140 = kw.get("k_140", None)
        self.k_141 = kw.get("k_141", None)
        self.k_142 = kw.get("k_142", None)
        self.k_143 = kw.get("k_143", None)
        self.k_144 = kw.get("k_144", None)
        self.k_145 = kw.get("k_145", None)
        self.k_146 = kw.get("k_146", None)
        self.k_147 = kw.get("k_147", None)
        self.k_148 = kw.get("k_148", None)
        self.k_149 = kw.get("k_149", None)
        self.k_15 = kw.get("k_15", None)
        self.k_150 = kw.get("k_150", None)
        self.k_151 = kw.get("k_151", None)
        self.k_152 = kw.get("k_152", None)
        self.k_153 = kw.get("k_153", None)
        self.k_154 = kw.get("k_154", None)
        self.k_155 = kw.get("k_155", None)
        self.k_156 = kw.get("k_156", None)
        self.k_157 = kw.get("k_157", None)
        self.k_158 = kw.get("k_158", None)
        self.k_159 = kw.get("k_159", None)
        self.k_16 = kw.get("k_16", None)
        self.k_160 = kw.get("k_160", None)
        self.k_161 = kw.get("k_161", None)
        self.k_162 = kw.get("k_162", None)
        self.k_163 = kw.get("k_163", None)
        self.k_164 = kw.get("k_164", None)
        self.k_165 = kw.get("k_165", None)
        self.k_166 = kw.get("k_166", None)
        self.k_167 = kw.get("k_167", None)
        self.k_168 = kw.get("k_168", None)
        self.k_169 = kw.get("k_169", None)
        self.k_17 = kw.get("k_17", None)
        self.k_170 = kw.get("k_170", None)
        self.k_171 = kw.get("k_171", None)
        self.k_172 = kw.get("k_172", None)
        self.k_173 = kw.get("k_173", None)
        self.k_174 = kw.get("k_174", None)
        self.k_175 = kw.get("k_175", None)
        self.k_176 = kw.get("k_176", None)
        self.k_177 = kw.get("k_177", None)
        self.k_178 = kw.get("k_178", None)
        self.k_179 = kw.get("k_179", None)
        self.k_18 = kw.get("k_18", None)
        self.k_180 = kw.get("k_180", None)
        self.k_181 = kw.get("k_181", None)
        self.k_182 = kw.get("k_182", None)
        self.k_183 = kw.get("k_183", None)
        self.k_184 = kw.get("k_184", None)
        self.k_185 = kw.get("k_185", None)
        self.k_186 = kw.get("k_186", None)
        self.k_187 = kw.get("k_187", None)
        self.k_188 = kw.get("k_188", None)
        self.k_189 = kw.get("k_189", None)
        self.k_19 = kw.get("k_19", None)
        self.k_190 = kw.get("k_190", None)
        self.k_191 = kw.get("k_191", None)
        self.k_192 = kw.get("k_192", None)
        self.k_193 = kw.get("k_193", None)
        self.k_194 = kw.get("k_194", None)
        self.k_195 = kw.get("k_195", None)
        self.k_196 = kw.get("k_196", None)
        self.k_197 = kw.get("k_197", None)
        self.k_198 = kw.get("k_198", None)
        self.k_199 = kw.get("k_199", None)
        self.k_2 = kw.get("k_2", None)
        self.k_20 = kw.get("k_20", None)
        self.k_200 = kw.get("k_200", None)
        self.k_201 = kw.get("k_201", None)
        self.k_202 = kw.get("k_202", None)
        self.k_203 = kw.get("k_203", None)
        self.k_204 = kw.get("k_204", None)
        self.k_205 = kw.get("k_205", None)
        self.k_206 = kw.get("k_206", None)
        self.k_207 = kw.get("k_207", None)
        self.k_208 = kw.get("k_208", None)
        self.k_209 = kw.get("k_209", None)
        self.k_21 = kw.get("k_21", None)
        self.k_210 = kw.get("k_210", None)
        self.k_211 = kw.get("k_211", None)
        self.k_212 = kw.get("k_212", None)
        self.k_213 = kw.get("k_213", None)
        self.k_214 = kw.get("k_214", None)
        self.k_215 = kw.get("k_215", None)
        self.k_216 = kw.get("k_216", None)
        self.k_217 = kw.get("k_217", None)
        self.k_218 = kw.get("k_218", None)
        self.k_219 = kw.get("k_219", None)
        self.k_22 = kw.get("k_22", None)
        self.k_220 = kw.get("k_220", None)
        self.k_221 = kw.get("k_221", None)
        self.k_222 = kw.get("k_222", None)
        self.k_223 = kw.get("k_223", None)
        self.k_224 = kw.get("k_224", None)
        self.k_225 = kw.get("k_225", None)
        self.k_226 = kw.get("k_226", None)
        self.k_227 = kw.get("k_227", None)
        self.k_228 = kw.get("k_228", None)
        self.k_229 = kw.get("k_229", None)
        self.k_23 = kw.get("k_23", None)
        self.k_230 = kw.get("k_230", None)
        self.k_231 = kw.get("k_231", None)
        self.k_232 = kw.get("k_232", None)
        self.k_233 = kw.get("k_233", None)
        self.k_234 = kw.get("k_234", None)
        self.k_235 = kw.get("k_235", None)
        self.k_236 = kw.get("k_236", None)
        self.k_237 = kw.get("k_237", None)
        self.k_238 = kw.get("k_238", None)
        self.k_239 = kw.get("k_239", None)
        self.k_24 = kw.get("k_24", None)
        self.k_240 = kw.get("k_240", None)
        self.k_241 = kw.get("k_241", None)
        self.k_242 = kw.get("k_242", None)
        self.k_243 = kw.get("k_243", None)
        self.k_244 = kw.get("k_244", None)
        self.k_245 = kw.get("k_245", None)
        self.k_246 = kw.get("k_246", None)
        self.k_247 = kw.get("k_247", None)
        self.k_248 = kw.get("k_248", None)
        self.k_249 = kw.get("k_249", None)
        self.k_25 = kw.get("k_25", None)
        self.k_250 = kw.get("k_250", None)
        self.k_251 = kw.get("k_251", None)
        self.k_252 = kw.get("k_252", None)
        self.k_253 = kw.get("k_253", None)
        self.k_254 = kw.get("k_254", None)
        self.k_255 = kw.get("k_255", None)
        self.k_256 = kw.get("k_256", None)
        self.k_257 = kw.get("k_257", None)
        self.k_258 = kw.get("k_258", None)
        self.k_259 = kw.get("k_259", None)
        self.k_26 = kw.get("k_26", None)
        self.k_260 = kw.get("k_260", None)
        self.k_261 = kw.get("k_261", None)
        self.k_262 = kw.get("k_262", None)
        self.k_263 = kw.get("k_263", None)
        self.k_264 = kw.get("k_264", None)
        self.k_265 = kw.get("k_265", None)
        self.k_266 = kw.get("k_266", None)
        self.k_267 = kw.get("k_267", None)
        self.k_268 = kw.get("k_268", None)
        self.k_269 = kw.get("k_269", None)
        self.k_27 = kw.get("k_27", None)
        self.k_270 = kw.get("k_270", None)
        self.k_271 = kw.get("k_271", None)
        self.k_272 = kw.get("k_272", None)
        self.k_273 = kw.get("k_273", None)
        self.k_274 = kw.get("k_274", None)
        self.k_275 = kw.get("k_275", None)
        self.k_276 = kw.get("k_276", None)
        self.k_277 = kw.get("k_277", None)
        self.k_278 = kw.get("k_278", None)
        self.k_279 = kw.get("k_279", None)
        self.k_28 = kw.get("k_28", None)
        self.k_280 = kw.get("k_280", None)
        self.k_281 = kw.get("k_281", None)
        self.k_282 = kw.get("k_282", None)
        self.k_283 = kw.get("k_283", None)
        self.k_284 = kw.get("k_284", None)
        self.k_285 = kw.get("k_285", None)
        self.k_286 = kw.get("k_286", None)
        self.k_287 = kw.get("k_287", None)
        self.k_288 = kw.get("k_288", None)
        self.k_289 = kw.get("k_289", None)
        self.k_29 = kw.get("k_29", None)
        self.k_290 = kw.get("k_290", None)
        self.k_291 = kw.get("k_291", None)
        self.k_292 = kw.get("k_292", None)
        self.k_293 = kw.get("k_293", None)
        self.k_294 = kw.get("k_294", None)
        self.k_295 = kw.get("k_295", None)
        self.k_296 = kw.get("k_296", None)
        self.k_297 = kw.get("k_297", None)
        self.k_298 = kw.get("k_298", None)
        self.k_299 = kw.get("k_299", None)
        self.k_3 = kw.get("k_3", None)
        self.k_30 = kw.get("k_30", None)
        self.k_300 = kw.get("k_300", None)
        self.k_301 = kw.get("k_301", None)
        self.k_302 = kw.get("k_302", None)
        self.k_303 = kw.get("k_303", None)
        self.k_304 = kw.get("k_304", None)
        self.k_305 = kw.get("k_305", None)
        self.k_306 = kw.get("k_306", None)
        self.k_307 = kw.get("k_307", None)
        self.k_308 = kw.get("k_308", None)
        self.k_309 = kw.get("k_309", None)
        self.k_31 = kw.get("k_31", None)
        self.k_310 = kw.get("k_310", None)
        self.k_311 = kw.get("k_311", None)
        self.k_312 = kw.get("k_312", None)
        self.k_313 = kw.get("k_313", None)
        self.k_314 = kw.get("k_314", None)
        self.k_32 = kw.get("k_32", None)
        self.k_33 = kw.get("k_33", None)
        self.k_34 = kw.get("k_34", None)
        self.k_35 = kw.get("k_35", None)
        self.k_36 = kw.get("k_36", None)
        self.k_37 = kw.get("k_37", None)
        self.k_38 = kw.get("k_38", None)
        self.k_39 = kw.get("k_39", None)
        self.k_4 = kw.get("k_4", None)
        self.k_40 = kw.get("k_40", None)
        self.k_41 = kw.get("k_41", None)
        self.k_42 = kw.get("k_42", None)
        self.k_43 = kw.get("k_43", None)
        self.k_44 = kw.get("k_44", None)
        self.k_45 = kw.get("k_45", None)
        self.k_46 = kw.get("k_46", None)
        self.k_47 = kw.get("k_47", None)
        self.k_48 = kw.get("k_48", None)
        self.k_49 = kw.get("k_49", None)
        self.k_5 = kw.get("k_5", None)
        self.k_50 = kw.get("k_50", None)
        self.k_51 = kw.get("k_51", None)
        self.k_52 = kw.get("k_52", None)
        self.k_53 = kw.get("k_53", None)
        self.k_54 = kw.get("k_54", None)
        self.k_55 = kw.get("k_55", None)
        self.k_56 = kw.get("k_56", None)
        self.k_57 = kw.get("k_57", None)
        self.k_58 = kw.get("k_58", None)
        self.k_59 = kw.get("k_59", None)
        self.k_6 = kw.get("k_6", None)
        self.k_60 = kw.get("k_60", None)
        self.k_61 = kw.get("k_61", None)
        self.k_62 = kw.get("k_62", None)
        self.k_63 = kw.get("k_63", None)
        self.k_64 = kw.get("k_64", None)
        self.k_65 = kw.get("k_65", None)
        self.k_66 = kw.get("k_66", None)
        self.k_67 = kw.get("k_67", None)
        self.k_68 = kw.get("k_68", None)
        self.k_69 = kw.get("k_69", None)
        self.k_7 = kw.get("k_7", None)
        self.k_70 = kw.get("k_70", None)
        self.k_71 = kw.get("k_71", None)
        self.k_72 = kw.get("k_72", None)
        self.k_73 = kw.get("k_73", None)
        self.k_74 = kw.get("k_74", None)
        self.k_75 = kw.get("k_75", None)
        self.k_76 = kw.get("k_76", None)
        self.k_77 = kw.get("k_77", None)
        self.k_78 = kw.get("k_78", None)
        self.k_79 = kw.get("k_79", None)
        self.k_8 = kw.get("k_8", None)
        self.k_80 = kw.get("k_80", None)
        self.k_81 = kw.get("k_81", None)
        self.k_82 = kw.get("k_82", None)
        self.k_83 = kw.get("k_83", None)
        self.k_84 = kw.get("k_84", None)
        self.k_85 = kw.get("k_85", None)
        self.k_86 = kw.get("k_86", None)
        self.k_87 = kw.get("k_87", None)
        self.k_88 = kw.get("k_88", None)
        self.k_89 = kw.get("k_89", None)
        self.k_9 = kw.get("k_9", None)
        self.k_90 = kw.get("k_90", None)
        self.k_91 = kw.get("k_91", None)
        self.k_92 = kw.get("k_92", None)
        self.k_93 = kw.get("k_93", None)
        self.k_94 = kw.get("k_94", None)
        self.k_95 = kw.get("k_95", None)
        self.k_96 = kw.get("k_96", None)
        self.k_97 = kw.get("k_97", None)
        self.k_98 = kw.get("k_98", None)
        self.k_99 = kw.get("k_99", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)
        self.year = kw.get("year", None)


    @staticmethod
    def updateConfig(id_, k, v, session):
        import time
        ts = int(time.time())
        sql = "UPDATE car_detail set " + str(k) + " = '" + str(v) + "',update_ts = " + str(ts) + " WHERE id = " + str(id_) + " LIMIT 1"
        res_info = session.execute(sql)
        return res_info


if __name__ == '__main__':
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(CarDetailModel):
        if not (str(k).startswith("_") or isinstance(getattr(CarDetailModel, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))
